summaryrefslogtreecommitdiffstats
path: root/src/gui/configuration/MIDIConfigurationPage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/configuration/MIDIConfigurationPage.cpp')
-rw-r--r--src/gui/configuration/MIDIConfigurationPage.cpp126
1 files changed, 63 insertions, 63 deletions
diff --git a/src/gui/configuration/MIDIConfigurationPage.cpp b/src/gui/configuration/MIDIConfigurationPage.cpp
index 3d46841..80ccf6b 100644
--- a/src/gui/configuration/MIDIConfigurationPage.cpp
+++ b/src/gui/configuration/MIDIConfigurationPage.cpp
@@ -41,25 +41,25 @@
#include <kcombobox.h>
#include <kconfig.h>
#include <kfiledialog.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qcstring.h>
-#include <qdatastream.h>
-#include <qframe.h>
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qobject.h>
-#include <qpushbutton.h>
-#include <qlayout.h>
-#include <qslider.h>
-#include <qspinbox.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qtabwidget.h>
-#include <qtooltip.h>
-#include <qwidget.h>
-#include <qcheckbox.h>
-#include <qhbox.h>
+#include <tqcheckbox.h>
+#include <tqcombobox.h>
+#include <tqcstring.h>
+#include <tqdatastream.h>
+#include <tqframe.h>
+#include <tqlabel.h>
+#include <tqlineedit.h>
+#include <tqobject.h>
+#include <tqpushbutton.h>
+#include <tqlayout.h>
+#include <tqslider.h>
+#include <tqspinbox.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqtabwidget.h>
+#include <tqtooltip.h>
+#include <tqwidget.h>
+#include <tqcheckbox.h>
+#include <tqhbox.h>
namespace Rosegarden
{
@@ -67,7 +67,7 @@ namespace Rosegarden
MIDIConfigurationPage::MIDIConfigurationPage(
RosegardenGUIDoc *doc,
KConfig *cfg,
- QWidget *parent,
+ TQWidget *parent,
const char *name):
TabbedConfigurationPage(cfg, parent, name),
m_midiPitchOctave(0)
@@ -77,22 +77,22 @@ MIDIConfigurationPage::MIDIConfigurationPage(
// ---------------- General tab ------------------
//
- QFrame *frame = new QFrame(m_tabWidget);
- QGridLayout *layout = new QGridLayout(frame, 9, 4, 10, 5);
+ TQFrame *frame = new TQFrame(m_tabWidget);
+ TQGridLayout *layout = new TQGridLayout(frame, 9, 4, 10, 5);
int row = 0;
layout->setRowSpacing(row, 15);
++row;
- QLabel *label = 0;
+ TQLabel *label = 0;
m_cfg->setGroup(GeneralOptionsConfigGroup);
- layout->addMultiCellWidget(new QLabel(i18n("Base octave number for MIDI pitch display"),
+ layout->addMultiCellWidget(new TQLabel(i18n("Base octave number for MIDI pitch display"),
frame), row, row, 0, 1);
- m_midiPitchOctave = new QSpinBox(frame);
+ m_midiPitchOctave = new TQSpinBox(frame);
m_midiPitchOctave->setMaxValue(10);
m_midiPitchOctave->setMinValue( -10);
m_midiPitchOctave->setValue(m_cfg->readNumEntry("midipitchoctave", -2));
@@ -104,10 +104,10 @@ MIDIConfigurationPage::MIDIConfigurationPage(
m_cfg->setGroup(GeneralOptionsConfigGroup);
- layout->addMultiCellWidget(new QLabel(i18n("Always use default studio when loading files"),
+ layout->addMultiCellWidget(new TQLabel(i18n("Always use default studio when loading files"),
frame), row, row, 0, 1);
- m_studio = new QCheckBox(frame);
+ m_studio = new TQCheckBox(frame);
m_studio->setChecked(m_cfg->readBoolEntry("alwaysusedefaultstudio", false));
layout->addWidget(m_studio, row, 2);
++row;
@@ -116,17 +116,17 @@ MIDIConfigurationPage::MIDIConfigurationPage(
//
m_cfg->setGroup(SequencerOptionsConfigGroup);
- label = new QLabel(i18n("Send all MIDI Controllers at start of each playback"), frame);
+ label = new TQLabel(i18n("Send all MIDI Controllers at start of each playback"), frame);
- QString controllerTip = i18n("Rosegarden can send all MIDI Controllers (Pan, Reverb etc) to all MIDI devices every\ntime you hit play if you so wish. Please note that this option will usually incur a\ndelay at the start of playback due to the amount of data being transmitted.");
- QToolTip::add
+ TQString controllerTip = i18n("Rosegarden can send all MIDI Controllers (Pan, Reverb etc) to all MIDI devices every\ntime you hit play if you so wish. Please note that this option will usually incur a\ndelay at the start of playback due to the amount of data being transmitted.");
+ TQToolTip::add
(label, controllerTip);
layout->addMultiCellWidget(label, row, row, 0, 1);
- m_sendControllersAtPlay = new QCheckBox(frame);
+ m_sendControllersAtPlay = new TQCheckBox(frame);
bool sendControllers = m_cfg->readBoolEntry("alwayssendcontrollers", false);
m_sendControllersAtPlay->setChecked(sendControllers);
- QToolTip::add
+ TQToolTip::add
(m_sendControllersAtPlay, controllerTip);
layout->addWidget(m_sendControllersAtPlay, row, 2);
++row;
@@ -135,15 +135,15 @@ MIDIConfigurationPage::MIDIConfigurationPage(
//
m_cfg->setGroup(SequencerOptionsConfigGroup);
- label = new QLabel(i18n("Sequencer timing source"), frame);
+ label = new TQLabel(i18n("Sequencer timing source"), frame);
layout->addMultiCellWidget(label, row, row, 0, 1);
m_timer = new KComboBox(frame);
layout->addMultiCellWidget(m_timer, row, row, 2, 3);
- QStringList timers = m_doc->getTimers();
+ TQStringList timers = m_doc->getTimers();
m_origTimer = m_doc->getCurrentTimer();
- QString currentTimer = m_cfg->readEntry("timer", m_origTimer);
+ TQString currentTimer = m_cfg->readEntry("timer", m_origTimer);
for (unsigned int i = 0; i < timers.size(); ++i) {
m_timer->insertItem(timers[i]);
@@ -160,27 +160,27 @@ MIDIConfigurationPage::MIDIConfigurationPage(
// SoundFont loading
//
- QLabel* lbl = new QLabel(i18n("Load SoundFont to SoundBlaster card at startup"), frame);
- QString tooltip = i18n("Check this box to enable soundfont loading on EMU10K-based cards when Rosegarden is launched");
- QToolTip::add(lbl, tooltip);
+ TQLabel* lbl = new TQLabel(i18n("Load SoundFont to SoundBlaster card at startup"), frame);
+ TQString tooltip = i18n("Check this box to enable soundfont loading on EMU10K-based cards when Rosegarden is launched");
+ TQToolTip::add(lbl, tooltip);
layout->addMultiCellWidget(lbl, row, row, 0, 1);
- m_sfxLoadEnabled = new QCheckBox(frame);
+ m_sfxLoadEnabled = new TQCheckBox(frame);
layout->addWidget(m_sfxLoadEnabled, row, 2);
- QToolTip::add(m_sfxLoadEnabled, tooltip);
+ TQToolTip::add(m_sfxLoadEnabled, tooltip);
++row;
- layout->addWidget(new QLabel(i18n("Path to 'asfxload' or 'sfxload' command"), frame), row, 0);
- m_sfxLoadPath = new QLineEdit(m_cfg->readEntry("sfxloadpath", "/bin/sfxload"), frame);
+ layout->addWidget(new TQLabel(i18n("Path to 'asfxload' or 'sfxload' command"), frame), row, 0);
+ m_sfxLoadPath = new TQLineEdit(m_cfg->readEntry("sfxloadpath", "/bin/sfxload"), frame);
layout->addMultiCellWidget(m_sfxLoadPath, row, row, 1, 2);
- m_sfxLoadChoose = new QPushButton("Choose...", frame);
+ m_sfxLoadChoose = new TQPushButton("Choose...", frame);
layout->addWidget(m_sfxLoadChoose, row, 3);
++row;
- layout->addWidget(new QLabel(i18n("SoundFont"), frame), row, 0);
- m_soundFontPath = new QLineEdit(m_cfg->readEntry("soundfontpath", ""), frame);
+ layout->addWidget(new TQLabel(i18n("SoundFont"), frame), row, 0);
+ m_soundFontPath = new TQLineEdit(m_cfg->readEntry("soundfontpath", ""), frame);
layout->addMultiCellWidget(m_soundFontPath, row, row, 1, 2);
- m_soundFontChoose = new QPushButton("Choose...", frame);
+ m_soundFontChoose = new TQPushButton("Choose...", frame);
layout->addWidget(m_soundFontChoose, row, 3);
++row;
@@ -193,14 +193,14 @@ MIDIConfigurationPage::MIDIConfigurationPage(
m_soundFontChoose->setEnabled(false);
}
- connect(m_sfxLoadEnabled, SIGNAL(toggled(bool)),
- this, SLOT(slotSoundFontToggled(bool)));
+ connect(m_sfxLoadEnabled, TQT_SIGNAL(toggled(bool)),
+ this, TQT_SLOT(slotSoundFontToggled(bool)));
- connect(m_sfxLoadChoose, SIGNAL(clicked()),
- this, SLOT(slotSfxLoadPathChoose()));
+ connect(m_sfxLoadChoose, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotSfxLoadPathChoose()));
- connect(m_soundFontChoose, SIGNAL(clicked()),
- this, SLOT(slotSoundFontChoose()));
+ connect(m_soundFontChoose, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotSoundFontChoose()));
layout->setRowStretch(row, 10);
@@ -210,8 +210,8 @@ MIDIConfigurationPage::MIDIConfigurationPage(
// -------------- Synchronisation tab -----------------
//
- frame = new QFrame(m_tabWidget);
- layout = new QGridLayout(frame, 7, 2, 10, 5);
+ frame = new TQFrame(m_tabWidget);
+ layout = new TQGridLayout(frame, 7, 2, 10, 5);
row = 0;
@@ -220,7 +220,7 @@ MIDIConfigurationPage::MIDIConfigurationPage(
// MIDI Clock and System Realtime Messages
//
- label = new QLabel(i18n("MIDI Clock and System messages"), frame);
+ label = new TQLabel(i18n("MIDI Clock and System messages"), frame);
layout->addWidget(label, row, 0);
m_midiSync = new KComboBox(frame);
layout->addWidget(m_midiSync, row, 1);
@@ -238,7 +238,7 @@ MIDIConfigurationPage::MIDIConfigurationPage(
// MMC Transport
//
- label = new QLabel(i18n("MIDI Machine Control mode"), frame);
+ label = new TQLabel(i18n("MIDI Machine Control mode"), frame);
layout->addWidget(label, row, 0);
m_mmcTransport = new KComboBox(frame);
@@ -257,7 +257,7 @@ MIDIConfigurationPage::MIDIConfigurationPage(
// MTC transport
//
- label = new QLabel(i18n("MIDI Time Code mode"), frame);
+ label = new TQLabel(i18n("MIDI Time Code mode"), frame);
layout->addWidget(label, row, 0);
m_mtcTransport = new KComboBox(frame);
@@ -274,13 +274,13 @@ MIDIConfigurationPage::MIDIConfigurationPage(
++row;
- QHBox *hbox = new QHBox(frame);
+ TQHBox *hbox = new TQHBox(frame);
hbox->setSpacing(5);
layout->addMultiCellWidget(hbox, row, row, 0, 1);
- label = new QLabel(i18n("Automatically connect sync output to all devices in use"), hbox);
+ label = new TQLabel(i18n("Automatically connect sync output to all devices in use"), hbox);
// layout->addWidget(label, row, 0);
- m_midiSyncAuto = new QCheckBox(hbox);
+ m_midiSyncAuto = new TQCheckBox(hbox);
// layout->addWidget(m_midiSyncAuto, row, 1);
m_midiSyncAuto->setChecked(m_cfg->readBoolEntry("midisyncautoconnect", false));
@@ -305,14 +305,14 @@ MIDIConfigurationPage::slotSoundFontToggled(bool isChecked)
void
MIDIConfigurationPage::slotSfxLoadPathChoose()
{
- QString path = KFileDialog::getOpenFileName(":SFXLOAD", QString::null, this, i18n("sfxload path"));
+ TQString path = KFileDialog::getOpenFileName(":SFXLOAD", TQString::null, this, i18n("sfxload path"));
m_sfxLoadPath->setText(path);
}
void
MIDIConfigurationPage::slotSoundFontChoose()
{
- QString path = KFileDialog::getOpenFileName(":SOUNDFONTS", "*.sb *.sf2 *.SF2 *.SB", this, i18n("Soundfont path"));
+ TQString path = KFileDialog::getOpenFileName(":SOUNDFONTS", "*.sb *.sf2 *.SF2 *.SB", this, i18n("Soundfont path"));
m_soundFontPath->setText(path);
}
@@ -365,7 +365,7 @@ MIDIConfigurationPage::apply()
int midiClock = m_midiSync->currentItem();
m_cfg->writeEntry("midiclock", midiClock);
// Now send it (OLD METHOD - to be removed)
//!!! No, don't remove -- this controls SPP as well doesn't it?
//
MappedEvent mEMIDIClock(MidiInstrumentBase, // InstrumentId
@@ -365,7 +365,7 @@ MIDIConfigurationPage::apply()
int midiClock = m_midiSync->currentItem();
m_cfg->writeEntry("midiclock", midiClock);
- // Now send it (OLD METHOD - to be removed)
+ // Now send it (OLD TQT_METHOD - to be removed)
//!!! No, don't remove -- this controls SPP as well doesn't it?
//